%global         pkgname Django

# Tests requiring Internet connections are disabled by default
# pass --with internet to run them (e.g. when doing a local rebuild
# for sanity checks before committing)
%bcond_with internet

Name:           python-django16

Version:        1.6.11.6
Release:        7%{?dist}
Summary:        A high-level Python Web framework

License:        BSD and MIT and Python
URL:            http://www.djangoproject.com/

# Django 1.6.11 is maintained past EOL by the Review Board developement team
# in a forked repository on github: https://github.com/beanbaginc/django
Source0:        https://downloads.reviewboard.org/releases/Django/1.6/Django-%{version}.tar.gz

#
# patches_base: 1.6.11.6
# https://github.com/beanbaginc/django/tree/1.6.11.6

Patch0001: 0001-setuptools.patch

BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  python-sphinx
BuildRequires:  python-setuptools


%description
Django is a high-level Python Web framework that encourages rapid
development and a clean, pragmatic design. It focuses on automating as
much as possible and adhering to the DRY (Don't Repeat Yourself)
principle. This compatibility version exists solely to support
Review Board. It is recommended not to use it for other purposes.


%prep
%setup -q -n %{pkgname}-%{version}
%patch0001 -p1

#remove pre-compiled egg-info
rm -rf Django.egg-info

# empty files
for f in \
    django/contrib/staticfiles/models.py \
    django/contrib/webdesign/models.py \
    django/contrib/humanize/models.py \
; do
  echo "# just a comment" > $f
done
echo "<!-- nothing -->" > django/contrib/flatpages/tests/templates/registration/login.html


%build
%py2_build_egg


%install
%py2_install_egg

%find_lang django
%find_lang djangojs
# append djangojs.lang to django.lang
cat djangojs.lang >> django.lang


# install man pages
mkdir -p %{buildroot}%{_mandir}/man1/
cp -p docs/man/* %{buildroot}%{_mandir}/man1/
mv %{buildroot}%{_mandir}/man1/django-admin.1 %{buildroot}%{_mandir}/man1/django16-admin.1
mv %{buildroot}%{_mandir}/man1/daily_cleanup.1 %{buildroot}%{_mandir}/man1/django16-daily_cleanup.1
mv %{buildroot}%{_mandir}/man1/gather_profile_stats.1 %{buildroot}%{_mandir}/man1/django16-gather_profile_stats.1


# Fix items in %%{_bindir}
mv %{buildroot}%{_bindir}/django-admin.py %{buildroot}%{_bindir}/django16-admin

# Make scripts executable
chmod a+x %{buildroot}/%{python2_sitelib}/%{pkgname}-%{version}-py%{python2_version}.egg/django/bin/profiling/gather_profile_stats.py
chmod a+x %{buildroot}/%{python2_sitelib}/%{pkgname}-%{version}-py%{python2_version}.egg/django/contrib/admin/bin/compress.py

# Replace shebangs in executable scripts
find %{buildroot} -type f -executable -exec sed -i '1s=^#!/usr/bin/\(python\|env python\)[23]\?=#!%{__python2}=' {} +

# remove .po files
find %{buildroot} -name "*.po" | xargs rm -f


%files -f django.lang
%license LICENSE
%license django/contrib/admin/static/admin/js/LICENSE-JQUERY.txt
%doc AUTHORS README.rst
%{python2_sitelib}/%{pkgname}-%{version}-py%{python2_version}.egg/
%{_bindir}/django16-admin
%{_mandir}/man1/*


%changelog
* Mon Dec 11 2017 Stephen Gallagher <sgallagh@redhat.com> - 1.6.11.6-7
- Drop the virtual Provides: it doesn't work properly

* Wed Oct 18 2017 Stephen Gallagher <sgallagh@redhat.com> - 1.6.11.6-6
- Explicitly Provides: python-django so it can work with existing packages

* Mon Oct 16 2017 Stephen Gallagher <sgallagh@redhat.com> - 1.6.11.6-5
- Update the License field

* Thu Oct 12 2017 Stephen Gallagher <sgallagh@redhat.com> - 1.6.11.6-4
- Clean up executable scripts
- Update python shebangs

* Wed Sep 27 2017 Stephen Gallagher <sgallagh@redhat.com> - 1.6.11.6-3
- Fixes from code review

* Thu Aug 31 2017 Stephen Gallagher <sgallagh@redhat.com> - 1.6.11.6-1
- Produce compatibility package for ReviewBoard

* Wed Apr 05 2017 Stephen Gallagher <sgallagh@redhat.com> - 1.6.11.6-1
- Update to the latest upstream security release 1.6.11.6
- https://www.reviewboard.org/news/2017/04/04/new-django-1-6-11-6-security-releases/

* Fri Mar 04 2016 Matthias Runge <mrunge@redhat.com> - 1.6.11-5
- fix CVE-2016-2512 (rhbz#1314345)
- fix CVE-2016-2513

* Mon Nov 30 2015 Matthias Runge <mrunge@redhat.com> - 1.6.11-4
- fix for CVE-2015-8213 (rhbz#1285279)
  backport thanks to https://github.com/beanbaginc/django/
- changed patches to use rdopkg for managing patches

* Wed Aug 26 2015 Matthias Runge <mrunge@redhat.com> - 1.6.11-3
- cherry-pick fix for Denial-of-service possibility in logout()
  view by filling session store CVE-2015-5963, CVE-2015-5964
- Prevented newlines from being accepted in some validators.

* Thu Jul 16 2015 Matthias Runge <mrunge@redhat.com> - 1.6.11-2
- cherry pick fix for CVE-2015-5143 (DoS by filling session store)
  rhbz#1239010

* Mon Mar 23 2015 Matthias Runge <mrunge@redhat.com> - 1.6.11-1
- fix CVE-2015-2316 (rhbz#1203615)
- fix CVE-2015-2317 (rhbz#1203618)

* Wed Jan 14 2015 Matthias Runge <mrunge@redhat.com> - 1.6.10-1
- fix CVE-2015-0219 (rhbz#1181939)
- fix CVE-2015-0220 (rhbz#1181943)
- fix CVE-2015-0221 (rhbz#1181946)
- fix CVE-2015-0222 (rhbz#1181951)

* Mon Jan 05 2015 Matthias Runge <mrunge@redhat.com> - 1.6.9-1
- update to 1.6.9

* Tue Nov 11 2014 Matthias Runge <mrunge@redhat.com> - 1.6.8-1
- update to 1.6.8

* Thu Sep 25 2014 Matthias Runge <mrunge@redhat.com> - 1.6.7-1
- update to 1.6.7
- don't own bash-completion dir.

* Thu Aug 21 2014 Matthias Runge <mrunge@redhat.com> - 1.6.6-1
- update to 1.6.6 
- fix CVE-2014-0480 (rhbz#1129950)
- fix CVE-2014-0481 (rhbz#1129952)
- fix CVE-2014-0482 (rhbz#1129954)
- fix CVE-2014-0483 (rhbz#1129959)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 28 2014 Kalev Lember <kalevlember@gmail.com> - 1.6.5-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4


* Fri May 16 2014 Matthias Runge <mrunge@redhat.com> - 1.6.5-1
- update to 1.6.5 CVE-2014-1418, CVE-2014-3730 (rhbz#1097935)

* Mon May 12 2014 Matthias Runge <mrunge@redhat.com> - 1.6.4-2
- don't hardcode python3.3

* Wed May 07 2014 Matthias Runge <mrunge@redhat.com> - 1.6.4-1
- update to 1.6.4 fix a potential regression in reverse()

* Tue Apr 22 2014 Matthias Runge <mrunge@redhat.com> - 1.6.3-1
- update to 1.6.3 fixing CVE-2014-0473 and CVE-2014-0474

* Thu Mar 27 2014 Matthias Runge <mrunge@redhat.com> - 1.6.2-2
- remove simplejson requirement
- make bash-completion a sub-package, both main packages can require

* Thu Feb 13 2014 Matthias Runge <mrunge@redhat.com> - 1.6.2-1
- update to 1.6.2 (rhbz#1027766)
- bash completion for python3-django-admin (rhbz#1035987)

* Mon Jan 27 2014 Matthias Runge <mrunge@redhat.com> - 1.5.4-3
- python-simplejson is not a hard requirement any more

* Thu Dec 19 2013 Dennis Gilmore <dennis@ausil.us> - 1.5.4-2
- disable python3 on epel7

* Sun Nov 24 2013 Matěj Cepl <mcepl@redhat.com> - 1.6-1
- update to 1.6 (rhbz#1027766)

* Tue Oct 29 2013 Matthias Runge <mrunge@redhat.com> - 1.5.5-2
- fix obsoletes

* Mon Oct 28 2013 Matthias Runge <mrunge@redhat.com> - 1.5.5-1
- update to 1.5.5 (rhbz#1023407)

* Mon Sep 16 2013 Matthias Runge <mrunge@redhat.com> - 1.5.4-1
- fix CVE-2013-1443 (DoS via large passwords), fixes rhbz#1008281

* Wed Sep 11 2013 Matthias Runge <mrunge@redhat.com> - 1.5.3-1
- fix CVE-2013-4315 (ssi issue), fixes rhbz 1004969

* Tue Aug 20 2013 Matthias Runge <mrunge@redhat.com> - 1.5.2-2
- increase obsoletes to 1.4.6-2

* Wed Aug 14 2013 Matthias Runge <mrunge@redhat.com> - 1.5.2-1
- security related update

* Mon Aug 05 2013 Matthias Runge <mrunge@redhat.com> - 1.5.1-3
- rebuild to fix build issues during mass rebuild.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Apr 02 2013 Matthias Runge <mrunge@redhat.com> - 1.5.1-1
- update to Django-1.5.1 (rhbz#929413)

* Wed Mar 27 2013 Miro Hrončok <mhroncok@redhat.com> - 1.5-3
- separated lang files for Python 2 and 3
- list %%files in Python 3 subpackage more precisely to not include locale files
- added %%doc to Python 3 subpackage
- removed trailing slash after %%{buildroot} to avoid double slash
- fixed bogus dates in %%changelog
- made %%check verbose, so it is not so boring to watch them run
- created python3 doc package
- created python3- prefixed symlink to manpage
- comment added about shared content - manpages

* Wed Mar 27 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 1.5-2
- Make the python3 subpackage install first, so that django-admin
  doesn't get overwritten.
- Don't own %%{python3_sitelib} itself, but only its contents.

* Wed Feb 27 2013 Matthias Runge <mrunge@redhat.com> - 1.5-1
- update to Django-1.5

* Thu Feb 21 2013 Matthias Runge <mrunge@redhat.com> - 1.4.5-2
- update to latest stable upstream version
- fix minor packaging issues introduced upstream

* Wed Feb 20 2013 Matthias Runge <mrunge@redhat.com> - 1.4.4-1
- update to 1.4.4 (rhbz #913024)
- Data leakage via admin history log CVE-2013-0305 (rhbz #913041)
- Formset denial-of-service CVE-2013-0306 (rhbz #913042)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 24 2013 Matthias Runge <mrunge@redhat.com> - 1.4.3-2
- also obsolete version 1.4.3-1

* Sun Jan 13 2013 Matthias Runge <mrunge@redhat.com> - 1.4.3-2
- own directories (rhbz#894533)

* Tue Dec 11 2012 Matthias Runge <mrunge@redhat.com> - 1.4.3-1
- security update to upstream version 1.4.3
  https://www.djangoproject.com/weblog/2012/dec/10/security/

* Fri Nov 16 2012 Bohuslav Kabrda <bkabrda@redhat.com> - 1.4.2-2
- Bump obsoletes version, since there is still Django-1.4.2-1 out there.
- Fix a provide that should allow users to use "django" instead of "Django".

* Thu Oct 18 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-1
- security update to upstream version 1.4.2-1
  https://www.djangoproject.com/weblog/2012/oct/17/security/

* Thu Sep 20 2012 Matthias Runge <mrunge@redhat.com> - 1.4.1-2
- fix provides: Django

* Wed Aug 01 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4.1-1
- update to 1.4.1 fixing CVE-2012-3442, CVE-2012-3443, and CVE-2012-3444

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 30 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4-4
- fix for FTBFS using python 2.7.3 (thanks to  M.Cepl)

* Tue Mar 27 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4-3
- revert change from 1.4-2
- really fix simplejson-import

* Tue Mar 27 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4-2
- fix simplejson-import (port from django-1.3-package)

* Sun Mar 25 2012 Michel Salim <salimma@fedoraproject.org> - 1.4-1
- Update to 1.4

* Mon Mar 19 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-9
- spec cleanup

* Sat Mar 17 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-8
- patch tests to work on koji (no internet connection)

* Sat Mar 10 2012 Michel Salim <salimma@fedoraproject.org> - 1.3.1-7
- Enable tests
- Now obsoletes (last Django release+1)
- Mark Bash completion script as a configuration file

* Fri Mar 09 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-6
- add additional provides django = %%{version}-%%{release}

* Wed Mar 07 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-5
- rename package to python-django

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Oct 12 2011 Michel Salim <salimma@fedoraproject.org> - 1.3.1-3
- Package bash completion script

* Sat Sep 10 2011 Michel Salim <salimma@fedoraproject.org> - 1.3.1-2
- Switch to the 'html' doc builder, for easier navigation without a web server

* Sat Sep 10 2011 Michel Salim <salimma@fedoraproject.org> - 1.3.1-1
- Update to 1.3.1
- Remove workaround for non-functional -doc generation
- Deduplicate file listing

* Wed Mar 30 2011 Steve Milner <me@stevemilner.org> - 1.3-2
- Fix for BZ#693865

* Wed Mar 30 2011 Steve Milner <me@stevemilner.org> - 1.3-1
- Fix for es_MX upstream bug
- Update for upstream release

* Wed Feb  9 2011 Steve Milner <me@stevemilner.org> - 1.2.5-1
- Fix for CVE-2011-0697

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan  3 2011 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.4-1
- Update for multiple security issues (see http://www.djangoproject.com/weblog/2010/dec/22/security/)

* Sat Oct  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.3-3
- Now build docs for F12+
- Added Django-remove-djangodocs-ext.patch

* Sat Oct  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.3-2
- Moved to dirhtml for documentation generation

* Mon Sep 13 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.3-1
- Update for http://www.djangoproject.com/weblog/2010/sep/10/123/

* Thu Sep  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.2-1
- Update for CVE-2010-3082 (see http://www.djangoproject.com/weblog/2010/sep/08/security-release/)
- Removed Django-hash-compat-13310.patch as it is already included in this release

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.2.1-6
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Tue Jun  8 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-5
- Added http://code.djangoproject.com/changeset/13310?format=diff&new=13310 per BZ#601212

* Thu Jun  3 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-4
- Include egg in >= rhel6

* Thu Jun  3 2010 Michel Salim <salimma@fedoraproject.org> - 1.2.1-3
- Use generated %%{name}.lang instead of including each locale file by hand
- Temporarily make main package provide -doc on Rawhide, to fix upgrade path
  until upstream documentation builds with Sphinx 1.0

* Thu May 27 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-2
- Allow for building docs in F13 as it's only F14 freaking out

* Tue May 25 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-1
- Update for new release.
- Added lang files per BZ#584866.
- Changed perms on %%{python_sitelib}/django/contrib/admin/media/js/compress.py
- Lots of explicit files listed in %%files in order to reduce duplicate file listings
- Docs are not built on F-13 for now

* Wed Oct 21 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1.1-2
- Removed po files per BZ#529188.

* Fri Oct  9 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1.1-1
- Update to fix http://www.djangoproject.com/weblog/2009/oct/09/security/
- Django-ignore-pyo-bz-495046.patch no longer needed.

* Wed Aug 26 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-4
- EL-4 shouldn't get the sphinx docs.

* Wed Aug 26 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-3
- ghosting admin py* is now FC9 and under.

* Thu Aug  6 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-2
- Applied Daniel Mach's patch from bz#516016.

* Sat Aug  1 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-1
- Update for Django 1.1 release.
- Moved /usr/bin/django-admin.py to /usr/bin/django-admin
- sed macro is now being used
- Patch for bz#495046 applied.

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-6
- Attempted combined spec for F12/11/10 and EL5

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-4
- Older builds must ghost django-admin.py[c,o]

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-3
- Bump for tag issue.

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-2
- Fix changelog.

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-1
- Upgrade for http://www.djangoproject.com/weblog/2009/jul/28/security/

* Thu Mar 12 2009 Michel Salim <salimma@fedoraproject.org> - 1.0.2-3
- Build HTML documentation (bug #484070)
- No longer excluding *.py? in bindir, F11's Python does not optimizes these

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Dec 14 2008 Michel Salim <salimma@fedoraproject.org> - 1.0.2-1
- Update to 1.0.2

* Sat Nov  1 2008 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.1-0.1.beta1
- Update to 1.0.1_beta_1

* Sat Sep  6 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-1
- Update to final 1.0 release

* Tue Sep  2 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-0.1.rc1%{?dist}
- CSRF security update: bz#460966

* Wed Aug 27 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-0.1.beta2
- Update to 1.0 beta2

* Sat Aug 23 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-0.1.beta1
- Update to 1.0 beta1

* Mon May 19 2008 Michel Salim <salimma@fedoraproject.org> - 0.96.2-1
- XSS security update: CVE-2008-2302 (bz# 442757-60)

* Sat Apr  5 2008 Michel Salim <salimma@fedoraproject.org> - 0.96.1-2
- Package .egg-info file on Fedora >= 9

* Thu Nov  1 2007 Michel Salim <michel.sylvan@gmail.com> 0.96.1-1
- i18n security update: CVE-2007-5712, bz#357051

* Sat Mar 24 2007 Michel Salim <michel.salim@gmail.com> - 0.96-1
- New upstream version

* Sun Jan 21 2007 Michel Salim <michel.salim@gmail.com> - 0.95.1-1
- Upstream security updates:
  http://www.djangoproject.com/weblog/2007/jan/21/0951/

* Sun Nov 12 2006 Michel Salim <michel.salim@gmail.com> - 0.95-1
- Initial package
